bayespy.inference.vmp.nodes.expfamily.ExponentialFamily.has_plotter
===================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.expfamily

.. automethod:: ExponentialFamily.has_plotter